*#================================================================#
*# Replication of König/Lin									 	  #
*# "Portfolio Allocation Patterns and Policymaking Effectiveness  # 
*#  in Minority Coalition Governance", published at EJPR. 		  #
*#																  #
*# Created by Nick Lin, 2020/07/05.							 	  #
*#================================================================#

version 15.1
cd wd = "$wd" // set your own working directory
use "KL_Minority_Data.dta", clear
set scheme s1mono

*#### Set up covariates for different models
global ctrl1 medInCab conflictCoalitionWt norPortSalience gpshare gparties extremeMin i.issueID
global ctrl2 betOppMedian conflictCoalitionWt norPortSalience gpshare gparties extremeMin i.issueID
global ctrl3 betOppMedian partnerBetween conflictCoalitionWt norPortSalience gpshare gparties extremeMin i.issueID

*### Replication code for Table 2 ###* 
stset durationReview, failure(passage) 

stcox $ctrl1, nohr vce(robust)
est store m1
stcox $ctrl2 if medInCab == 0, nohr vce(robust) 
est store m2
stcox $ctrl3 if medInCab == 0, nohr vce(robust)
est store m3

esttab m1 m2 m3, b(%10.3f) se scalars (N ll) star(+ 0.10 * 0.05 ** 0.01) noomitted /*
	*/ keep(medInCab betOppMedian partnerBetween  conflictCoalitionWt norPortSalience gpshare gparties extremeMin)  /*
	*/ order(medInCab betOppMedian partnerBetween  conflictCoalitionWt norPortSalience gpshare gparties extremeMin) /*
	*/ coeflabels(medInCab "Median In Cabinet" betOppMedian "Sandwich Median Party" partnerBetween "Sandwiched Ruling Partner" /*
	*/ 			  conflictCoalitionWt "Coalition Divisiveness" gparties "Number of Government Parties" /*
	*/ 			  norPortSalience "Portfolio Salience" gpshare "Seat Share of Cabinet Parties" extremeMin "Extreme Minister")

	
*### Replication code for Figure 3 ###*
gen month = durationReview / 30

*# Hypothesis 1: Median in Cabinet vs Not
stcox $ctrl1, nohr vce(robust) basesurv(m1_base)
gen m1_baseT = m1_base^(exp(-.169))
sort month

# delimit ;
twoway (line m1_base month, lpattern(solid)) (line m1_baseT month, lpattern(dash)), 
   legend(row(2) col(1) pos(7) order(1 "Median out of Cabinet"  2 "Median in Cabinet") 
   ring(0) size(medsmall))  
   ylabel(0(0.2)1) 
   xtitle(Length of Parliamentary Deliberation (Months)) 
   ytitle(Probability of Survival) 
   name(cox1, replace);
# delimit cr

*# Hypothesis 2: Sadwiched Median vs. Others
stcox $ctrl3 if medInCab == 0, nohr vce(robust) basesurv(m3_base)
gen m3_baseT = m3_base^(exp(0.095))
sort month

# delimit ;
twoway (line m3_base month, lpattern(solid)) (line m3_baseT month, lpattern(dash)),
   legend(row(2) col(1) pos(7) order(1 "Otherwise"  2 "Sandwiched Median") 
   ring(0) size(medsmall))  
   ylabel(0(0.2)1) 
   xtitle(Length of Parliamentary Deliberation (Months)) 
   ytitle(Probability of Survival)
   name(cox2, replace);
# delimit cr

gr combine cox1 cox2, col(2) ycommon imargin(tiny)
gr export Fig3_Survival.eps, replace

	
*### Replication code for Table 3 ###*
nbreg numQuestion $ctrl1 if year >= 2004, robust
est store m1
nbreg numQuestion $ctrl2 if medInCab ==0 & year >= 2004, robust
est store m2
nbreg numQuestion $ctrl3 if medInCab ==0 & year >= 2004, robust
est store m3

esttab m1 m2 m3, b(%10.3f) se scalars (N ll) star(+ 0.10 * 0.05 ** 0.01) noomitted /*
	*/ keep(medInCab betOppMedian partnerBetween  conflictCoalitionWt norPortSalience gpshare gparties extremeMin _cons)  /*
	*/ order(medInCab betOppMedian partnerBetween  conflictCoalitionWt norPortSalience gpshare gparties extremeMin _cons) /*
	*/ coeflabels(medInCab "Median In Cabinet" betOppMedian "Sandwich Median Party" partnerBetween "Sandwiched Ruling Partner" /*
	*/ 			  conflictCoalitionWt "Coalition Divisiveness" gparties "Number of Government Parties" /*
	*/ 			  norPortSalience "Portfolio Salience" gpshare "Seat Share of Cabinet Parties" extremeMin "Extreme Minister" _cons "Constant")


*### Replication code for Figfure 4 ###*
*##  Note: the Clarify package is needed.

tab issueID, gen(isid)
set seed 0325

*# Simulations using Model 1
global ctrl medInCab conflictCoalitionWt norPortSalience gpshare extremeMin isid2-isid7 isid10-isid12
   
gen predMd = .
gen diffMedInOut = .

forvalues sim = 1/1000 {

capture drop b1-b16
estsimp nbreg numQuestion $ctrl if year >= 2004, robust

setx mean
setx extremeMin 0

	local a = 1 
	forvalues i = 0/1 {
	
	setx medInCab `i'
	simqi, pv genpv(pred)
	sum pred
	replace predMd=r(mean) in `a'
	capture drop pred
	
	local a = `a' + 1
	}
	
replace diffMedInOut = predMd[2] - predMd[1] in `sim'
} 
drop b1-b16

*# Simulations using Model 2
global ctrl betOppMedian conflictCoalitionWt norPortSalience gpshare extremeMin isid3-isid7 isid10-isid11 
		
gen diffSanMedMin = .

forvalues sim = 1/1000 {

capture drop b1-b14

estsimp nbreg numQuestion $ctrl if medInCab ==0 & year >= 2004, robust

setx mean
setx extremeMin 0

	local a = 1 
	forvalues i = 0/1 {
	
	setx betOppMedian `i' 
	simqi, pv genpv(pred)
	sum pred
	replace predMd=r(mean) in `a'
	capture drop pred
	
	local a = `a' + 1
	}
	
replace diffSanMedMin = predMd[2] - predMd[1] in `sim'
} 

keep diffMedInOut diffSanMedMin

*# Produce the plot
su diffMedInOut, detail
global diffMedInOut=r(p50) 

histogram diffMedInOut, bin(50) percent fcolor(gs5) lcolor(white) xline($diffMedInOut, lpattern(dash) lcolor(gray)) ///
		  ytitle(Percentage) yscale(range(0 5)) xtitle(Expected Number of Committee Questions) title(Median in Cabinet vs. Otherwise)  
graph save nb1, replace

su diffSanMedMin, detail
global diffSanMedMin=r(p50) 

histogram diffSanMedMin, bin(50) percent fcolor(gs9) lcolor(white) xline($diffSanMedMin, lpattern(dash) lcolor(gray)) ///
		  ytitle(Percentage) yscale(range(0 5)) xtitle(Expected Number of Committee Questions) title(Sandwiched Median vs. Otherwise) 
graph save nb2, replace

gr combine nb1.gph nb2.gph, xcommon rows(2) 
graph export Fig4_Questions.eps, replace


*### Replication code for Table 1 & Table 4 ###*

preserve
collapse medInCab betOppMedian minInBetweenAlt partnerBetween conflictCoalitionWt divCpMedianMV issueID govtID norPortSalience, by(govt ministryEn)   

*# Stats for Table 1
tab medInCab
tab betOppMedian if medInCab == 0
tab minInBetweenAlt if medInCab == 0
tab partnerBetween if medInCab == 0

*# Table 4
logit medInCab conflictCoalitionWt divCpMedianMV norPortSalience i.issueID i.govtID, robust
est store m1

logit betOppMedian conflictCoalitionWt divCpMedianMV norPortSalience i.issueID i.govtID if medInCab == 0, robust
est store m2

esttab m1 m2, b(%10.3f) se scalars (N ll) star(+ 0.10 * 0.05 ** 0.01) noomitted /*
*/ keep(conflictCoalitionWt divCpMedianMV norPortSalience _cons)  /*
*/ order(conflictCoalitionWt divCpMedianMV norPortSalience _cons) /*
*/ coeflabels(conflictCoalitionWt "Coalition Divisiveness" divCpMedianMV "Median-Compromise Distance" ///
        norPortSalience "Portfolio Salience" _cons "Constant")
restore
